buildingspy — BuildingsPy documentation

### Navigation

- index
- modules |
- next |
- Home > BuildingsPy

# buildingspy

buildingspy is a Python package that can be used

> - to run Modelica simulations using Dymola,
> - to process `*.mat` output files that were generated by Dymola or OpenModelica, and
> - to run unit tests as part of the library development.

The package provides functions to extract data series from the output file for further use in the python packages matplotlib for plotting and SciPy for scientific computing.

Contents:

- Install and Uninstall BuildingsPy
- Running simulations
- Reading output files, plotting results and reporting simulation output
  - File reader
  - Plotter
  - Reporter
- Examples
  - Running a Simulation
  - Plotting of Time Series
- Development
- Copyright and License
- Acknowledgments
- Revisions
  - BuildingsPy Changelog

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- Home > BuildingsPy